from itertools import count

from sushi_rest import get_menu, generate_order


def naive_is_in_order(menu, order):
    is_in = dict()

    for plate_name_menu in menu.keys():
        is_in[plate_name_menu] = False

        for plate_name_order in order:
            if plate_name_menu == plate_name_order:
                is_in[plate_name_menu] = True

    return is_in


def almost_naive_is_in_order(menu, order):
    is_in = dict()

    for plate_name_menu in menu.keys():
        is_in[plate_name_menu] = False

        for plate_name_order in order:
            if plate_name_menu == plate_name_order:
                is_in[plate_name_menu] = True
                break

    return is_in


def is_in_order(menu, order):
    is_in = dict()
    order = set(order)  # THIS IS ESSENTIAL, OTHERWISE IT'S LIKE almost_naive_is_in_order

    for plate_name_menu in menu.keys():
        if plate_name_menu in order:
            is_in[plate_name_menu] = True
        else:
            is_in[plate_name_menu] = False

    return is_in


def count_plates(order):
    dict_count = dict()

    for plate_name_menu in order:
        if plate_name_menu in dict_count:
            dict_count[plate_name_menu] += 1
        else:
            dict_count[plate_name_menu] = 1

    return dict_count


def add_missing_plates(count_plates_dict, menu):
    missing_plates = menu.keys() - count_plates_dict.keys()

    for missing_plate_name in missing_plates:
        count_plates_dict[missing_plate_name] = 0

    return count_plates_dict


def main():
    menu = get_menu()
    order = generate_order()

    # How many plates are in the order?
    print(f"There are {len(order)} plates in the order", "\n")

    # How many unique plates are in the order?
    print(f"There are {len(set(order))} unique plates in the order", "\n")

    # For each plate in the menu, find if it is in the order
    print("Indices:", is_in_order(menu, order), "\n")

    # Create a dictionary that counts how often each plate from the menu appears in the order.
    count_plates_dict = count_plates(order)
    print(count_plates(order), "\n")

    # Add to the previous dictionary all menu plates, even if they don't appear in the order.
    print(add_missing_plates(count_plates_dict, menu), "\n")


if __name__ == '__main__':
    main()
